<?php

namespace plugin\cms\controller;

use plugin\cms\model\CmsCateArticle;
use plugin\cms\model\CmsCategory;
use think\admin\Controller;
use think\admin\helper\QueryHelper;

class Category extends Controller
{
    /**
     * 栏目管理
     * @auth true
     * @menu true
     * @login true
     * @return void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function index()
    {
        $this->title = '栏目列表';
        CmsCategory::mQuery()->layTable(function () {
        }, static function (QueryHelper $query) {
            $query->equal('status')->like('name');
        });
    }

    /**
     * 添加栏目
     * @auth true
     * @menu true
     * @login true
     * @return void
     */
    public function add()
    {
        $this->title = '添加栏目';
        CmsCategory::mForm('form');
    }

    /**
     * 编辑栏目
     * @auth true
     * @menu true
     * @login true
     * @return void
     */
    public function edit()
    {
        $this->title = '编辑栏目';
        $this->id = $this->request->param('id', 0, 'intval');         //当前栏目ID
        CmsCategory::mForm('form');
    }

    /**
     * 删除栏目
     * @auth true
     * @menu true
     * @login true
     * @return void
     */
    public function remove()
    {
        CmsCategory::mDelete('id');
    }

    public function _delete_filter()
    {
        $id = $this->request->post('id');
        $children_count = CmsCategory::where('pid', $id)->count();
        if ($children_count > 0) {
            $this->error("该栏目下有子栏目，不能删除！");
        }
        $articles_count = CmsCateArticle::where('cid', $id)->count();
        if ($articles_count > 0) {
            $this->error("该栏目下有文章，不能删除！");
        }
        return true;
    }

    /**
     * 状态切换
     * @auth true
     * @menu true
     * @login true
     * @return void
     */
    public function status()
    {
        CmsCategory::mSave($this->_vali([
            'id.require' => '栏目ID不能为空',
            'status.in:0,1'  => '状态值范围异常！',
            'status.require' => '状态值不能为空！',
        ]), 'id');
    }

    public function sort()
    {
        CmsCategory::mSave($this->_vali([
            'id.require' => '栏目ID不能为空',
            'sort.require' => '排序值不能为空！',
            'sort.number'  => '排序必须为数字！',
            'sort.between:0,9999' => '排序值必须为0~9999之间！',
        ]), 'id');
    }
}