<?php

namespace plugin\inspection\controller\api\auth;

use plugin\inspection\controller\api\Auth;
use plugin\inspection\model\InspectionRecord;
use plugin\ticket\model\TicketTicket;

class Ticket extends Auth
{
    public function add()
    {
        $record_id = $this->request->post('record_id');
        $record = null;
        if (!empty($record_id)) {
            /** @var InspectionRecord $record */
            $record = InspectionRecord::mk()->where('id', $record_id)->find();
            if (empty($record)) {
                $this->error('记录不存在');
            }
        }
        $lat = $this->request->post('lat');
        $lng = $this->request->post('lng');
        $type_id = $this->request->post('type_id');
        $title = $this->request->post('title');
        $content = $this->request->post('content');
        $ticket_region = $this->request->post('ticket_region');
        $ticket_address = $this->request->post('ticket_address');
        $imgs = $this->request->post('imgs');
        $ticket_project_use = $this->request->post('ticket_project_use');
        $ticket_work_use = $this->request->post('ticket_work_use');
        $ticket_price =$this->request->post('ticket_price');
        $data = [
            'uid' => $this->staff->id,
            'utype' => $this->staff->id,
            'type_id' => $type_id,
            'title' => $title,
            'content' => $content,
            'contact_name' => $this->staff->name,
            'contact_phone' => $this->staff->phone,
            'ticket_region' => $ticket_region,
            'ticket_address' => $ticket_address,
            'lat' => $lat,
            'lng' => $lng,
            'imgs' => $imgs,
            'status' => 1,
            'state' => 0,
        ];
        if (!empty($record)) {
            $ticket = $record->ticket()->save($data);
        } else {
            $ticket = TicketTicket::create($data);
        }
        $ticket->verify()->save([
            'staff_id' => $this->staff->id,
            'content' => $content,
            'imgs' => $imgs,
            'work_days' => $ticket_work_use
        ]);
        $ticket->save();
        $this->success("工单创建成功", $ticket);
    }

    public function list()
    {
        $status = $this->request->get('status', null);
        $query = TicketTicket::query(); // ->where(['fz_user_id'=>$this->staff->id])
        if ($status) {
            $query->where('staff_status', $status);
        }
        $pageData = $query->paginate();
        $this->success('获取工单列表', $pageData);
    }

    public function info()
    {
        $id = $this->request->get('id');
        $ticket = TicketTicket::query()
//            ->where(['fz_user_id'=>$this->staff->id])
            ->with(['verify', 'repair'])->findOrEmpty($id);
        if ($ticket->isEmpty()) $this->error('工单不存在');
        $this->success('获取工单详情', $ticket);
    }

    public function verify()
    {
        $id = $this->request->get('id');
        /** @var TicketTicket $ticket */
        $ticket = TicketTicket::query()->where(['fz_user_id'=>$this->staff->id])->findOrEmpty($id);
        if ($ticket->isEmpty()) $this->error('工单不存在');
        $data = $this->_vali([
            'content.require' => '现场核实内容不能为空',
            'imgs.default' => '',
            'work_days.default' => '',
        ]);
        $ticket->verify()->save([
            'staff_id' => $this->staff->id,
            'content' => $data['content'],
            'imgs' => $data['imgs'],
            'work_days' => $data['work_days']
        ]);
        // 已现场核实
        $ticket->staff_status = 1;
        $ticket->save();
        $this->success('工单现场核实成功');
    }

    public function repair()
    {
        $id = $this->request->get('id');
        /** @var TicketTicket $ticket */
        $ticket = TicketTicket::query()->where(['fz_user_id'=>$this->staff->id])->findOrEmpty($id);
        if ($ticket->isEmpty()) $this->error('工单不存在');
        $data = $this->_vali([
            'content.require' => '维修内容不能为空',
            'imgs.default' => '',
        ]);
        $ticket->repair()->save([
            'staff_id' => $this->staff->id,
            'content' => $data['content'],
            'imgs' => $data['imgs'],
        ]);
        // 已维修
        $ticket->staff_status = 2;
        $ticket->save();
        $this->success('工单维修成功');
    }
}